@@ -3,26 +3,26 @@
 #' Apply function to position coordinates
 #'
 #' The function xy stat applies a function to the x- and y-coordinates of a
-#' layers positions by group. The \code{stat_centroid()} and
-#' \code{stat_midpoint()} functions are convenience wrappers for calculating
-#' centroids and midpoints. \code{stat_funxy()} by default leaves the data
+#' layers positions by group. The `stat_centroid()` and
+#' `stat_midpoint()` functions are convenience wrappers for calculating
+#' centroids and midpoints. `stat_funxy()` by default leaves the data
 #' as-is, but can be supplied functions and arguments.
 #'
 #' @inheritParams ggplot2::stat_identity
-#' @param funx,funy A \code{function} to call on the layer's \code{x} and
-#'   \code{y} positions respectively.
-#' @param argx,argy A named \code{list} containing arguments to the \code{funx},
-#'   and \code{funy} function calls.
-#' @param crop_other A \code{logical} of length one; whether the other data
-#'   should be fitted to the length of \code{x} and \code{y} (default:
-#'   \code{TRUE}). Useful to set to \code{FALSE} when \code{funx} or \code{funy}
+#' @param funx,funy A `function` to call on the layer's `x` and
+#'   `y` positions respectively.
+#' @param argx,argy A named `list` containing arguments to the `funx`,
+#'   and `funy` function calls.
+#' @param crop_other A `logical` of length one; whether the other data
+#'   should be fitted to the length of `x` and `y` (default:
+#'   `TRUE`). Useful to set to `FALSE` when `funx` or `funy`
 #'   calculate summaries of length one that need to be recycled.
 #'
 #' @details This statistic only makes a minimal attempt at ensuring that the
 #'   results from calling both functions are of equal length. Results of length
 #'   1 are recycled to match the longest length result.
 #'
-#' @return A \code{StatFunxy} ggproto object, that can be added to a plot.
+#' @return A `StatFunxy` ggproto object, that can be added to a plot.
 #' @export
 #'
 #' @examples
@@ -49,33 +49,28 @@ stat_funxy <-
            position = "identity", ..., funx = force, funy = force,
            argx = list(), argy = list(), crop_other = TRUE,
            show.legend = NA, inherit.aes = TRUE) {
-    if (!is.function(funx)) {
-      stop("The `funx` argument must be a function.", call. = FALSE)
-    }
-    funx <- force(funx)
-    if (!is.function(funy)) {
-      stop("The `funy` argument must be a function.", call. = FALSE)
-    }
-    funy <- force(funy)
-    if (!is.list(argx) | !is.list(argy)) {
-      stop("The `argx` and `argy` arguments must be lists.", call. = FALSE)
-    } else {
-      if (length(argx) > 0) {
-        if (is.null(names(argx))) {
-          stop("The `argx` list must have named elements.", call. = FALSE)
-        }
-      }
-      if (length(argy) > 0) {
-        if (is.null(names(argy))) {
-          stop("The `argy` list must have named elements.", call. = FALSE)
-        }
-      }
-    }
+    stopifnot(
+      "The `funx` argument must be a function." =
+        is.function(funx),
+      "The `funy` argument must be a function." =
+        is.function(funy),
+      "The `argx` and `argy` arguments must be lists." =
+        is.list(argx) & is.list(argy),
+      "The `argx` list must have named elements" =
+        length(argx) == sum(nzchar(names(argx))),
+      "The `argy` list must have named elements" =
+        length(argy) == sum(nzchar(names(argy)))
+    )
 
     layer(
-      data = data, mapping = mapping, stat = StatFunxy, geom = geom,
-      position = position, show.legend = show.legend, inherit.aes = inherit.aes,
-      params = list(
+      data        = data,
+      mapping     = mapping,
+      stat        = StatFunxy,
+      geom        = geom,
+      position    = position,
+      show.legend = show.legend,
+      inherit.aes = inherit.aes,
+      params      = list2(
         funx = funx, funy = funy,
         argx = argx, argy = argy,
         crop_other = crop_other,
@@ -135,6 +130,6 @@ StatFunxy <- ggproto(
     # Combine data
     data <- c(other, list(x = x, y = y))
     data <- do.call(vec_recycle_common, data)
-    .int$new_data_frame(data)
+    new_data_frame(data)
   }
 )
