@@ -9,6 +9,8 @@ grab_axis <- function(plot, where = "b") {
 }
 
 test_that("guide_axis_minor works on x-scales", {
+  rlang::local_options(lifecycle_verbosity = "quiet")
+
   test <- base + scale_x_continuous(guide = "axis_minor")
   test <- grab_axis(test, "b")
   # Grab tick positions
@@ -21,6 +23,8 @@ test_that("guide_axis_minor works on x-scales", {
 })
 
 test_that("guide_axis_minor works on y-scales", {
+  rlang::local_options(lifecycle_verbosity = "quiet")
+
   test <- base + scale_y_continuous(guide = "axis_minor")
   test <- grab_axis(test, "l")
   # Grab tick positions
@@ -28,11 +32,17 @@ test_that("guide_axis_minor works on y-scales", {
   expect_length(unique(test), 3) # 1 at base, 1 for long ticks, 1 for short
 
   ctrl <- grab_axis(base, "l")
-  ctrl <- grid::convertX(ctrl$grobs[[2]]$x, "cm", valueOnly = TRUE)
+  if (utils::packageVersion("ggplot2") <= "3.4.2") {
+    ctrl <- grid::convertX(ctrl$grobs[[2]]$x, "cm", valueOnly = TRUE)
+  } else {
+    ctrl <- grid::convertX(ctrl$grobs[[1]]$x, "cm", valueOnly = TRUE)
+  }
   expect_length(unique(ctrl), 2)
 })
 
 test_that("guide_axis_minor works on top x-scales", {
+  rlang::local_options(lifecycle_verbosity = "quiet")
+
   test <- base + scale_x_continuous(guide = "axis_minor", position = "top")
   ctrl <- base + scale_x_continuous(position = "top")
   test <- grab_axis(test, "t")
@@ -41,11 +51,17 @@ test_that("guide_axis_minor works on top x-scales", {
   expect_length(unique(test), 3) # 1 at base, 1 for long ticks, 1 for short
 
   ctrl <- grab_axis(ctrl, "t")
-  ctrl <- grid::convertX(ctrl$grobs[[2]]$y, "cm", valueOnly = TRUE)
+  if (utils::packageVersion("ggplot2") <= "3.4.2") {
+    ctrl <- grid::convertX(ctrl$grobs[[2]]$y, "cm", valueOnly = TRUE)
+  } else {
+    ctrl <- grid::convertX(ctrl$grobs[[1]]$y, "cm", valueOnly = TRUE)
+  }
   expect_length(unique(ctrl), 2)
 })
 
 test_that("guide_axis_minor works on right y-scales", {
+  rlang::local_options(lifecycle_verbosity = "quiet")
+
   test <- base + scale_y_continuous(guide = "axis_minor", position = "right")
   ctrl <- base + scale_y_continuous(position = "right")
   test <- grab_axis(test, "r")
@@ -59,6 +75,8 @@ test_that("guide_axis_minor works on right y-scales", {
 })
 
 test_that("minor tick theme element works", {
+  rlang::local_options(lifecycle_verbosity = "quiet")
+
   ctrl <- base + scale_x_continuous(guide = "axis_minor")
   test <- ctrl + theme(ggh4x.axis.ticks.length.minor = rel(2))
 
@@ -70,6 +88,7 @@ test_that("minor tick theme element works", {
 })
 
 test_that("NULL breaks return zeroGrob as labels", {
+  rlang::local_options(lifecycle_verbosity = "quiet")
   g <- base + scale_x_continuous(guide = "axis_minor", breaks = NULL)
   g <- ggplotGrob(g)
   g <- g$grobs[[which(g$layout$name == "axis-b")]]$children[[1]]
@@ -77,10 +96,18 @@ test_that("NULL breaks return zeroGrob as labels", {
 })
 
 test_that("guide_axis_minor errors upon misuse", {
+  rlang::local_options(lifecycle_verbosity = "quiet")
+
   g <- ggplot(iris, aes(Sepal.Width, Sepal.Length)) +
     geom_point(aes(colour = Species)) +
     scale_colour_discrete(guide = "axis_minor")
-  expect_snapshot_error(ggplotGrob(g))
+
+  if (utils::packageVersion("ggplot2") <= "3.4.2") {
+    expect_snapshot_error(ggplotGrob(g))
+  } else {
+    expect_snapshot_warning(ggplotGrob(g))
+  }
+
 
   gui <- guide_axis_minor()
   gui$available_aes <- "z"
